@@ -10,11 +10,11 @@
 ##' @usage
 ##' 
 ##' \method{plot}{jointSurroPenal}(x, type.plot = "Hazard", conf.bands=TRUE,
-##' pos.legend = "topright", cex.legend=0.7, main, Xlab = "Time", Ylab
-##' = "Baseline hazard function", xmin = 0, xmax = NULL, ylim = c(0,1), endpoint = 2, 
-##' scale = 1, ...)
+##' pos.legend = "topright", cex.legend=0.7, main, Xlab = "Time", 
+##' Ylab = "Baseline hazard function", median = TRUE, xmin = 0, xmax = NULL, 
+##' ylim = c(0,1), endpoint = 2, scale = 1, ...)
 ##' @param x An object inheriting from \code{jointSurroPenal} class
-##' (output from calling \code{jointSurroPenal} function).
+##' (output from calling the function \code{jointSurroPenal} ).
 ##' @param type.plot A character string specifying the type of curve. Possible
 ##' value are "Hazard", or "Survival". The default is "Hazard". Only the first
 ##' letters are required, e.g "Haz", "Su".
@@ -27,6 +27,7 @@
 ##' @param cex.legend Character expansion factor *relative* to current
 ##' 'par("cex")'. Default is 0.7.
 ##' @param main Title of plot.
+##' @param median Logical value. Determines whether survival median will be plotted. Default is TRUE.
 ##' @param Xlab Label of x-axis. Default is '"Time"'.
 ##' @param Ylab Label of y-axis. Default is '"Baseline hazard function"'.
 ##' @param xmin Minimum value for x-axis, the default is \code{0}. 
@@ -55,8 +56,8 @@
 ##' 
 ##' data(dataOvarian)
 ##' joint.surro.ovar <- jointSurroPenal(data = dataOvarian, n.knots = 8, 
-##'                 init.kappa = c(2000,1000), indice.alpha = 0, nb.mc = 200, 
-##'                 scale = 1/365)
+##'                 init.kappa = c(2000,1000), indicator.alpha = 0, 
+##'                 nb.mc = 200, scale = 1/365)
 ##' 
 ##' # Baseline Hazards fonctions for both the surrogate endpoint 
 ##' # and the true endpoint
@@ -73,7 +74,7 @@
 ##' 
 "plot.jointSurroPenal" <- function (x, type.plot="Hazard", conf.bands=TRUE, pos.legend = "topright", 
                                     cex.legend = 0.7, main, Xlab = "Time", Ylab = "Baseline hazard function", 
-                                    xmin = 0, xmax = NULL, ylim = c(0,1), endpoint = 2, scale = 1, ...)
+                                    median = TRUE, xmin = 0, xmax = NULL, ylim = c(0,1), endpoint = 2, scale = 1, ...)
 {
   color = 2
   # gestion de l'echelle des temps
@@ -109,13 +110,15 @@
   			if (conf.bands){
   				matplot(x$xT, x$survT, col=color, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, main=main, xlim = xlim, ylim = ylim, ...)
   				matlines(x$xT, x$survT, col=color+(i-1), type="l", lty=c(1,2,2), ...)
+  				if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
   			}else{
   				plot(x$xT, x$survT[,1], col=color, type="l", lty=1, xlab=Xlab,ylab=Ylab, main=main, xlim = xlim, ylim = ylim, ...)
   				lines(x$xT, x$survT[,1], col=color+(i-1), type="l", lty=1, ...)
+  				if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
   			}
   	}
   	
-  	legend(pos.legend, c("True endpoint related event"), lty=1, col=color+(0), cex=cex.legend, ...)
+  	legend(pos.legend, c("For the true endpoint"), lty=1, col=color+(0), cex=cex.legend, ...)
 	}
 	
 	if(endpoint == 0){ # surrogate endpoint
@@ -133,13 +136,15 @@
 	    if (conf.bands){
 	      matplot(x$xS, x$survS, col=color + 1, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, main=main, xlim = xlim, ylim = ylim, ...)
 	      matlines(x$xS, x$survS, col=color + 1, type="l", lty=c(1,2,2), ...)
+	      if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
 	    }else{
 	      plot(x$xS, x$survS[,1], col=color + 1, type="l", lty=1, xlab=Xlab,ylab=Ylab, main=main, xlim = xlim, ylim = ylim, ...)
 	      lines(x$xS, x$survS[,1], col=color + 1, type="l", lty=1, ...)
+	      if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
 	    }
 	  }
 	  
-	  legend(pos.legend, c("Surrogate endpoint related event"), lty=1, col=color + 1, cex=cex.legend, ...)
+	  legend(pos.legend, c("For the surrogate endpoint"), lty=1, col=color + 1, cex=cex.legend, ...)
 	}
 	
 	if(endpoint == 2){ # both surrogate and true endpoint
@@ -166,14 +171,16 @@
 	    if(conf.bands){
 	      matplot(x$xT, matS, col=c(color,color,color,color+1,color+1,color+1), type="l", lty=c(1,2,2,1,2,2), xlab=Xlab,ylab=Ylab, main=main, xlim = xlim, ylim = ylim, ...)
 	      matlines(x$xT, matS, col=c(color,color,color,color+1,color+1,color+1), type="l", lty=c(1,2,2,1,2,2), ...)
+	      if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
 	    }else{
 	      matS2 <- matS[,c(1,4)]
 	      matplot(x$xT, matS2, col=c(color,color+1), type="l", lty=c(1,1), xlab = Xlab,ylab = Ylab, main = main, xlim = xlim, ylim = ylim, ...)
 	      matlines(x$xT, matS2, col=c(color,color+1), type="l", lty=c(1,1), ...)
+	      if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
 	    }
 	  }
 	  
-	  legend(pos.legend, c("True endpoint related event", "Surrogate endpoint related event"), lty=c(1,1), col=c(color,color+1), cex=cex.legend, ...)
+	  legend(pos.legend, c("For the true endpoint", "For the surrogate endpoint"), lty=c(1,1), col=c(color,color+1), cex=cex.legend, ...)
 	}
     return(invisible())
 }
