@@ -8,7 +8,7 @@
 #' @usage
 #' 
 #' \method{plot}{longiPenal}(x, type.plot = "Hazard", conf.bands=TRUE,
-#' pos.legend= "topright", cex.legend=0.7, main, color, Xlab = "Time", Ylab =
+#' pos.legend= "topright", cex.legend=0.7, main, color, median=TRUE, Xlab = "Time", Ylab =
 #' "Hazard function", ...)
 #' @param x A joint model for longitudinal outcome and a terminal event, i.e. a
 #' \code{longiPenal} class object (output from calling \code{longiPenal}
@@ -26,6 +26,7 @@
 #' 'par("cex")'. Default is 0.7
 #' @param main title of plot
 #' @param color color of the curve (integer)
+#' @param median Logical value. Determines whether survival median will be plotted. Default is TRUE.
 #' @param Xlab Label of x-axis. Default is '"Time"'
 #' @param Ylab Label of y-axis. Default is '"Hazard function"'
 #' @param ... other unused arguments
@@ -64,44 +65,48 @@
 #' }
 #' 
 #' 
-"plot.longiPenal" <- function (x, type.plot="Hazard", conf.bands=TRUE, pos.legend="topright", cex.legend=0.7, main, color=2, Xlab = "Time", Ylab = "Hazard function", ...)
+"plot.longiPenal" <- function (x, type.plot="Hazard", conf.bands=TRUE, pos.legend="topright", cex.legend=0.7, main, color=2, median=TRUE, Xlab = "Time", Ylab = "Hazard function", ...)
 {
-
+  
   plot.type <- charmatch(type.plot, c("Hazard", "Survival"),nomatch = 0)
   if (plot.type == 0) {
     stop("estimator must be Hazard or Survival")
   }
-
+  
   if(missing(main))
     main<-""
-
+  
   if(plot.type==1){ # hazard
-
+    
     if(conf.bands){
       matplot(x$xD[-1,1], x$lamD[-1,,1], col=color, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, main=main, ...)
     }else{
       plot(x$xD[-1,1], x$lamD[-1,1,1], col=color, type="l", lty=1, xlab=Xlab,ylab=Ylab, main=main, ...)
     }
-
+    
   }else{ # survival
-	if (missing(Ylab)) Ylab <- "Baseline survival function"
+    if (missing(Ylab)) Ylab <- "Baseline survival function"
     if (x$typeof == 0){
       if (conf.bands){
         matplot(x$xD[,1], x$survD[,,1], col=color, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, main=main, ...)
-     }else{
+        if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
+      }else{
         plot(x$xD[,1], x$survD[,1,1], col=color, type="l", lty=1, xlab=Xlab,ylab=Ylab, main=main, ...)
-       }
+        if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
+      }
     }else{
       if (conf.bands){
         matplot(x$xSuD[,1], x$survD[,,1], col=color, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, main=main, ...)
-       }else{
+        if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
+      }else{
         plot(x$xSuD[,1], x$survD[,1,1], col=color, type="l", lty=1, xlab=Xlab,ylab=Ylab, main=main, ...)
+        if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
       }
     }
-
+    
   }
-
+  
   legend(pos.legend, c("event"), lty=1, col=color, cex=cex.legend, ...)
-
+  
   return(invisible())
 }
