@@ -13,7 +13,7 @@ contains
     ! n= taille du vecteur frail qui vaut nombre de sujet+2 pour vs et vt
     ! i = position du premier individu du cluster, sera increentee de la taille du cluster + 1 a la sortie de la fonction
      use var_surrogate
-    use comon, only: ve,vedc,eta,theta
+    use comon, only: ve,vedc,eta
 
     IMPLICIT NONE
     integer ::j,k !n=taille du tableau frail
@@ -63,13 +63,13 @@ contains
     ! frail= vecteur des frailties de taille nombre d'individus dans le cluster ou on se trouve
     ! i = position du cluster sur lequel on se trouve
      use var_surrogate
-    use comon, only: ve,vedc,eta,theta,alpha
+    use comon, only: ve,vedc,alpha
 
     IMPLICIT NONE
-    integer ::j,k,n 
+    integer ::n 
     integer,intent(in):: i
     !integer,intent(in)::n
-    double precision:: s1,C1,c2,c3,c4,c5,vs,vt
+    double precision:: c2,c3,c4,vs
     double precision,intent(in),dimension(1)::frail
 
     ! fin declaration et debut de la fonction
@@ -110,13 +110,13 @@ contains
     ! frail= vecteur des frailties de taille nombre d'individus dans le cluster ou on se trouve
     ! i = position du cluster sur lequel on se trouve
      use var_surrogate
-    use comon, only: ve,vedc,eta,theta,alpha
+    use comon, only: eta
 
     IMPLICIT NONE
-    integer ::j,k,n_i,dimInt 
+    integer ::n_i 
     integer,intent(in):: i
     !integer,intent(in)::n
-    double precision:: s1,C1,c2,c3,c4,c5,vs,vt
+    double precision:: C1,c2,c3,c4
     double precision,intent(in),dimension(nsujeti(i))::frail
 
     ! fin declaration et debut de la fonction
@@ -147,12 +147,12 @@ contains
     use comon, only: eta
 
     IMPLICIT NONE
-    integer ::j,k,n_i,dimInt 
+    integer ::n_i
     integer,intent(in):: i
     !integer,intent(in)::n
-    double precision:: s1,c1,c3,c4,vs,vt
+    double precision:: c1,c3,c4
     double precision,intent(in),dimension(:)::frail
-    double precision,dimension(1,nsujeti(i))::c5,frail_mat
+    !double precision,dimension(1,nsujeti(i))::c5,frail_mat
     double precision,dimension(1,1)::c2
 
     ! fin declaration et debut de la fonction
@@ -266,32 +266,32 @@ contains
     ! vti= frailtie niveau essai associe a t
     ! j = individu j du cluster i
     ! npoint = nombre de point de quadrature
-     use var_surrogate, only:vs_i,vt_i,individu_j,posind_i,ui_chap,theta2,const_res5,const_res4,&
-        deltastar,delta,adaptative,xx1,ww1,estim_wij_chap,nparamfrail,ntrials,nsujeti,&
-        invBi_chol_Essai,invBi_cholDet_Essai,invBi_chol_Individuel,essai_courant,ui_chap_Essai,&
+     use var_surrogate, only:posind_i,ui_chap,theta2,const_res5,const_res4,& !vs_i,vt_i,individu_j
+        deltastar,delta,adaptative,xx1,ww1,& !estim_wij_chap,nparamfrail,ntrials,nsujeti
+        invBi_chol_Individuel,& !invBi_chol_Essai,invBi_cholDet_Essai,essai_courant,ui_chap_Essai
         alpha_ui,frailt_base,switch_adaptative
-    use comon, only: eta,lognormal,theta,ve,nsujet,eta,I_hess,H_hess,model,invBi_cholDet
-    use parameters, only: maxiter
+    use comon, only: eta,lognormal,ve,eta,invBi_cholDet !I_hess,H_hess,model,nsujet,theta
+    !use parameters, only: maxiter
     !use mod_Adaptative ! pour lintegrant a maximiser pour l'adaptative
 !    use func_adaptative
     use Autres_fonctions
-    use tailles, only:npmax 
+    !use tailles, only:npmax 
     !use optim_SCL_0
     IMPLICIT NONE
     integer,intent(in):: j,npoint1
     double precision,intent(in)::vsi,vti,ui
     double precision,dimension(npoint1):: xx
-    integer::i,ier,istop,ss,sss,ni,model_save,nparamfrail_save,maxiter_save,k,nmax,indicej,&
-             np,indice_B_essai,indice_ind_util_essai,non_conv
-    integer::frail_essai_deja_est  ! variable qui dit si pour un essai donne l'on a deja estimes les vsi et vti (1) ou non (0)
+    !integer::i,ier,istop,ss,sss,ni,model_save,nparamfrail_save,maxiter_save,k,nmax,indicej, & 
+    !         np,indice_B_essai,indice_ind_util_essai,non_conv
+    !integer::frail_essai_deja_est  ! variable qui dit si pour un essai donne l'on a deja estimes les vsi et vti (1) ou non (0)
     integer,parameter::effet=0,np_1=1
-    double precision::ca,cb,dd
-    double precision::res
-    double precision, dimension(2)::k0
+    !double precision::ca,cb,dd
+    !double precision::res
+    !double precision, dimension(2)::k0
 !    double precision, dimension(1)::v,b
-    double precision, dimension(2)::b_i      ! pour les 2 parametres des effets aleatoires a predire niveau essai
-    double precision, dimension(2,2)::v_i    ! pour les 2 parametres des effets aleatoires a predire niveau essai
-    double precision, allocatable, dimension(:,:)::H_hessOut,HIH,HIHOut,IH,invBi_chol
+    !double precision, dimension(2)::b_i      ! pour les 2 parametres des effets aleatoires a predire niveau essai
+    !double precision, dimension(2,2)::v_i    ! pour les 2 parametres des effets aleatoires a predire niveau essai
+    !double precision, allocatable, dimension(:,:)::H_hessOut,HIH,HIHOut,IH,invBi_chol
 
     if(adaptative .and. switch_adaptative==1) then ! on effectue le changement de variable 
         xx=ui_chap(posind_i-1+j,1)+dsqrt(2.d0)*xx1*invBi_chol_Individuel(posind_i-1+j)            
@@ -380,8 +380,8 @@ contains
     double precision,intent(in)::vsi,vti,ui,uti
     double precision, dimension(:,:),allocatable::m1,m3
     double precision, dimension(:,:),allocatable::m
-    integer ::ii,jj,npg,kk,cpt
-    double precision::ss1,ss2,auxfunca,ss,wsij,wtij,test,rho
+    integer ::ii,jj,npg
+    double precision::ss1,auxfunca,ss,wsij,wtij,test,rho
     double precision, dimension(ndim)::xxl !vecteur qui contiendra à chaque fois les points de quadrature
     double precision,dimension(ndim,ndim)::invBi_chol_Essai_k ! pour recuperer les matrice B_k dans le vecteur des matrices B des essais K
 
@@ -528,7 +528,7 @@ contains
     double precision, intent(in)::mu1,vc1
     double precision,dimension(1:nsimu)::frailij,usim
     double precision:: c1,c2,c3,c4
-    integer::n,ttt
+    integer::n
 
     ! fin declaration et debut de la fonction
     !!print*,"j=",j,"posind_i=",posind_i-1,"posind_i+j=",posind_i-1+j
@@ -622,15 +622,15 @@ contains
         ! ui=  fragilites niveau essai base a S
         ! uti= fragilites niveau essai base a T
         ! frailij= frailty au niveau individuel generes suivant la gaussienne multivariee centree
-        use var_surrogate, only: delta,deltastar,const_res4,const_res5,Vect_sim_MC,frailt_base,posind_i
-        use comon, only: eta,ve
+        use var_surrogate, only: delta,deltastar,const_res4,const_res5,frailt_base,posind_i
+        use comon, only: ve
         IMPLICIT NONE
         integer,intent(in):: j,nsimu,ndim
         double precision,intent(in)::vsi,vti,ui,uti
         double precision, intent(in)::mu1
         double precision,dimension(nsimu,ndim),intent(in)::frailij
-        double precision,dimension(:,:),allocatable::usim
-        integer::n,l
+        !double precision,dimension(:,:),allocatable::usim
+        integer::n !l
         
         
         ! Je calcule pour chaque individu du cluster par vectorisation son integrale par gaussHermite non adaptative
@@ -678,7 +678,7 @@ contains
     
         double precision,intent(out)::ss
         integer,intent(in)::nnodes,position_i
-        double precision::auxfunca,func6JL,func7J,func8J,func9J
+        double precision::auxfunca
         integer::j,methodGH
         double precision,dimension(nnodes):: xx1,ww1
         
@@ -742,7 +742,7 @@ contains
     
         double precision,intent(out)::ss
         integer,intent(in)::nnodes,position_i
-        double precision::auxfunca,func6JL,func7J,func8J,func9J
+        double precision::auxfunca
         integer::j
         double precision,dimension(nnodes):: xx1,ww1
         
@@ -788,13 +788,13 @@ contains
     ! frail= vecteur des frailties de taille nombre d'individus dans le cluster ou on se trouve
     ! i = position du cluster sur lequel on se trouve
      use var_surrogate
-    use comon, only: ve,vedc,eta,theta,alpha
+    use comon, only: ve,vedc,eta,alpha
 
     IMPLICIT NONE
-    integer ::j,k,n,dimInt 
+    integer ::n,dimInt 
     integer,intent(in):: i
     !integer,intent(in)::n
-    double precision:: s1,C1,c2,c3,c4,c5,vs,vt
+    double precision:: C1,c2,c3,c4,vs
     double precision,intent(in),dimension(:)::frail
 
     ! fin declaration et debut de la fonction
@@ -823,7 +823,7 @@ contains
     ! n= taille du vecteur frail
     ! i = position du premier individu du cluster, sera increentee de la taille du cluster + 1 a la sortie de la fonction
      use var_surrogate
-    use comon, only: ve,vedc,eta,theta
+    use comon, only: ve,vedc
 
     IMPLICIT NONE
     integer ::j,k !n=taille du tableau frail
@@ -879,7 +879,7 @@ contains
     !use tailles
     !use comon,only:nig,auxig,alpha,theta,res1,res3,aux1,cdc
     use var_surrogate
-    use comon, only: ve,vedc,eta,theta
+    use comon, only: ve,eta
 
     IMPLICIT NONE
     integer ::j,n,k !n=taille du tableau frail
@@ -935,7 +935,7 @@ contains
     ! ndim= dimension de l'integrale ou nombre d'individu du cluster
     ! i position du premier individu du cluster dans lequel on integre
     
-    use var_surrogate, only: npoint,adaptative
+    use var_surrogate, only: npoint
     use donnees ! pour les points et poids de quadrature (fichier Adonnees.f90)
     
     implicit none
@@ -1013,7 +1013,7 @@ recursive function gaussHermMultMC(frail1,frail,i,k,x,w,inc) result(herm)
    ! inc un increment pour le controle, vaut 0 initialement
    
    use var_surrogate, only:adaptative
-   use comon, only:invBi_cholDet
+   !use comon, only:invBi_cholDet
    
    implicit none
    
@@ -1066,12 +1066,12 @@ recursive function gaussHermMultMC(frail1,frail,i,k,x,w,inc) result(herm)
     ! i = position du cluster sur lequel on se trouve
 
     use var_surrogate
-    use comon, only: ve,vedc,eta,theta,alpha,res1,aux1
+    use comon, only: ve,vedc
 
     IMPLICIT NONE
-    integer ::j,k,n
+    integer ::n
     integer,intent(in):: i
-    double precision:: C1,c2,c3,c4,c5,vs,vt
+    double precision:: C1,c2,c3,c4,vs,vt
     double precision,dimension(2),intent(in)::frail
     double precision, dimension(1,2)::m1,m3
     double precision, dimension(1,1)::m
@@ -1107,14 +1107,14 @@ recursive function gaussHermMultMC(frail1,frail,i,k,x,w,inc) result(herm)
     ! i = position du cluster sur lequel on se trouve
 
     use var_surrogate
-    use comon, only: ve,vedc,eta,theta,alpha,res1,aux1
+    use comon, only: ve,vedc,alpha !res1
 
     IMPLICIT NONE
-    integer ::j,k,n
+    integer ::n
     integer,intent(in):: i
-    double precision:: s1,C1,m,c2,c3,c4,c5,vs,vt
+    double precision:: C1,c2,c3,c4,vs
     double precision,intent(in)::frail
-    double precision, dimension(1,2)::m1,m3
+    !double precision, dimension(1,2)::m1,m3
     
     n=nsujeti(i)
     vs=frail
@@ -1135,14 +1135,14 @@ recursive function gaussHermMultMC(frail1,frail,i,k,x,w,inc) result(herm)
     !use tailles
     !use comon,only:nig,auxig,alpha,theta,res1,res3,aux1,cdc
     use var_surrogate
-    use comon, only: ve,vedc,eta,theta,alpha,res1,aux1
+    use comon, only: alpha !vedc
 
     IMPLICIT NONE
-    integer ::j !n=taille du tableau frail
+    !integer ::j !n=taille du tableau frail
     integer,intent(in):: i
-    double precision:: s1,C1,m,c2,c3,c4,c5,vs,vt
+    double precision:: C1,c2,c3,c4,vs
     double precision,intent(in)::frail
-    double precision, dimension(1,2)::m1,m3
+    !double precision, dimension(1,2)::m1,m3
 
     ! fin declaration et debut de la fonction
     
@@ -1166,7 +1166,7 @@ recursive function gaussHermMultMC(frail1,frail,i,k,x,w,inc) result(herm)
     !use tailles
     !use comon,only:nig,auxig,alpha,theta,res1,res3,aux1,cdc
     use var_surrogate
-    use comon, only: ve,vedc,eta,theta
+    use comon, only: ve,eta,theta
 
     IMPLICIT NONE
     integer ::j,n !n=taille du tableau frail
@@ -1237,9 +1237,9 @@ recursive function gaussHermMultMC(frail1,frail,i,k,x,w,inc) result(herm)
   !1 integrale
   double precision function func1(arg,ndim)
     implicit none
-    integer ::i
+    !integer ::i
     integer, intent(in)::ndim
-    double precision ::s,s2
+    double precision ::s
     double precision,dimension(ndim), intent(in):: arg
     double precision,parameter::pi=3.141592653589793d0
     
