@@ -9,8 +9,8 @@
     use comon,only: etaD,betaD, etaT, betaT, nstRec, &
     t0,t1,t1dc,c,cdc,nsujet,nva,nva1,nva2,& 
     effet,stra,ve,vedc,ng,g,nig,indic_ALPHA,ALPHA,theta,& 
-    nfam,  indic_xi, xi, eta, & !for family 
-    aux1,aux2,res1,res3,kkapa
+    nfam,fam,fsize,indic_xi,xi,eta, & !for family 
+    aux1,aux2,res1,res3,kkapa,nb_gl
     use residusM
     !use comongroup,only:the1,the2
     use comongroup,only:vet,vet2
@@ -32,7 +32,7 @@
     ,res3dc,integrale1,integrale2,integrale3
     double precision,dimension(nfam)::integrale3f
     double precision::int
-        
+
     kkapa=k0
     choix=0
     ig=0
@@ -169,7 +169,7 @@
     end do
 
     choix = 3
-    call gaulagJf(int)
+    call gaulagJf(int,nb_gl)
     res=int
     
 !************* FIN INTEGRALES **************************
@@ -199,6 +199,18 @@
             Rdc(k)=aux1(k)
             Ndc(k)=cdc(k)
         end do
+        
+        k=0
+        do i= 1,ng
+            do j=1,fsize(fam(i))
+                cumulhaz1(i,j) = res1(k+j)
+                cumulhaz0(i,j) = res3(k+j)
+                cumulhazdc(i,j) = aux1(k+j)
+            end do
+            if(i.lt.ng.and.fam(i).ne.fam(i+1)) then 
+                k = k +fsize(fam(i))
+            end if
+        end do
     end if
 !Ad:
 123     continue
