@@ -15,7 +15,7 @@
 !ResMartingaleEvent=c(Res_martingale,Res_martingaledc,Res_martingale2)
 !frailtyEstimates=c(frailtypred,frailtypred2,frailtyvar,frailtyvar2,frailtyCorr)
 
-    subroutine jointMultiv(nobsEvent,nz0,k0,tt00,tt10,tt0meta0,tt1meta0,ic0,icmeta0, &
+    subroutine joint_multiv(nobsEvent,nz0,k0,tt00,tt10,tt0meta0,tt1meta0,ic0,icmeta0, &
     groupe0,groupe0meta,groupe0dc,tt0dc0,tt1dc0,icdc0,nbvar,vax0,vaxmeta0,vaxdc0,noVarEvent, &
     maxIteration,initialize,np,b,H_hessOut,HIHOut,resOut,LCV,critCV,x1Out,lamOut,xSu1,suOut,x2Out, & 
     lam2Out,xSu2,su2Out,x3Out,lam3Out,xSu3,su3Out,typeof0,equidistant0,nbIntervEvent, &
@@ -127,10 +127,10 @@
     double precision,dimension(nobsEvent(3))::Resmartingales,frailtypreds,frailtysds,frailtyvars
     double precision,dimension(:),allocatable::linearpreds,martingaleCoxs,times
     integer::timedepMul,nbinnerknots0Mul,qorder0Mul
-    double precision,dimension(:),allocatable::filtretps0Mul
+    integer,dimension(:),allocatable::filtretps0Mul
     double precision,dimension(0:100,1)::BetaTpsMatMul
     double precision,dimension(3)::EPS
-
+    
 
 !     do i=1,5
 !         write(*,*)groupe0(i),groupe0meta(i),groupe0dc(i)
@@ -251,7 +251,7 @@
         xTOuts,lamTOuts,xSuTs,suTOuts,typeof0,equidistant0,nbintervR0,mt1, &    
         ni,cpts,ier,k0s,ddls,istop,shapeweibs,scaleweibs,100,zis,Resmartingales,martingaleCoxs,&
         frailtypreds,frailtyvars,frailtysds,linearpreds,times,0,tt10,0, &
-        timedepMul,nbinnerknots0Mul,qorder0Mul,filtretps0Mul,BetaTpsMatMul,EPS)
+        timedepMul,nbinnerknots0Mul,qorder0Mul,filtretps0Mul,BetaTpsMatMul,EPS,20)
 
 
         deallocate(filtretps0Mul)
@@ -308,7 +308,7 @@
         xTOuts,lamTOuts,xSuTs,suTOuts,typeof0,equidistant0,nbintervM0,mt3, &    
         ni,cpts,ier,k0s,ddls,istop,shapeweibs,scaleweibs,100,zis,Resmartingales,martingaleCoxs,&
         frailtypreds,frailtyvars,frailtysds,linearpreds,times,0,tt10,0, &
-        timedepMul,nbinnerknots0Mul,qorder0Mul,filtretps0Mul,BetaTpsMatMul,EPS)
+        timedepMul,nbinnerknots0Mul,qorder0Mul,filtretps0Mul,BetaTpsMatMul,EPS,20)
 
         deallocate(filtretps0Mul)
         deallocate(H_hess0,HIH0,zis,str00)
@@ -363,7 +363,7 @@
         xTOuts,lamTOuts,xSuTs,suTOuts,typeof0,equidistant0,nbintervDC0,mt2, &    
         ni,cpts,ier,k0s,ddls,istop,shapeweibs,scaleweibs,mt12,zis,Resmartingales,martingaleCoxs,&
         frailtypreds,frailtyvars,frailtysds,linearpreds,times,0,tt10,0, &
-        timedepMul,nbinnerknots0Mul,qorder0Mul,filtretps0Mul,BetaTpsMatMul,EPS)
+        timedepMul,nbinnerknots0Mul,qorder0Mul,filtretps0Mul,BetaTpsMatMul,EPS,20)
 
         deallocate(filtretps0Mul)
         deallocate(H_hess0,HIH0,zis,str00)
@@ -1576,7 +1576,7 @@
 
     return
 
-    end subroutine jointMultiv
+    end subroutine joint_multiv
 
 
 !========================== VECSPLI ==============================
